==> pmml-model-gwt-1.2.14.jar: org/dmg/pmml/ModelExplanation.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;choice>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_2}PredictiveModelQuality" maxOccurs="unbounded" minOccurs="0"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_2}ClusteringModelQuality" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;/choice>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Correlations" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "predictiveModelQualities",
    "clusteringModelQualities",
    "correlations"
})
@XmlRootElement(name = "ModelExplanation", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_0)
public class ModelExplanation
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    private List<Extension> extensions;
    @XmlElement(name = "PredictiveModelQuality", namespace = "http://www.dmg.org/PMML-4_2")
    private List<PredictiveModelQuality> predictiveModelQualities;
    @XmlElement(name = "ClusteringModelQuality", namespace = "http://www.dmg.org/PMML-4_2")
    private List<ClusteringModelQuality> clusteringModelQualities;
    @XmlElement(name = "Correlations", namespace = "http://www.dmg.org/PMML-4_2")
    private Correlations correlations;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the predictiveModelQualities property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the predictiveModelQualities property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPredictiveModelQualities().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PredictiveModelQuality }
     * 
     * 
     */
    public List<PredictiveModelQuality> getPredictiveModelQualities() {
        if (predictiveModelQualities == null) {
            predictiveModelQualities = new ArrayList<PredictiveModelQuality>();
        }
        return this.predictiveModelQualities;
    }

    /**
     * Gets the value of the clusteringModelQualities property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the clusteringModelQualities property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getClusteringModelQualities().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ClusteringModelQuality }
     * 
     * 
     */
    public List<ClusteringModelQuality> getClusteringModelQualities() {
        if (clusteringModelQualities == null) {
            clusteringModelQualities = new ArrayList<ClusteringModelQuality>();
        }
        return this.clusteringModelQualities;
    }

    /**
     * Gets the value of the correlations property.
     * 
     * @return
     *     possible object is
     *     {@link Correlations }
     *     
     */
    public Correlations getCorrelations() {
        return correlations;
    }

    /**
     * Sets the value of the correlations property.
     * 
     * @param correlations
     *     allowed object is
     *     {@link Correlations }
     *     
     */
    public ModelExplanation setCorrelations(Correlations correlations) {
        this.correlations = correlations;
        return this;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public ModelExplanation addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasPredictiveModelQualities() {
        return ((this.predictiveModelQualities!= null)&&(this.predictiveModelQualities.size()> 0));
    }

    public ModelExplanation addPredictiveModelQualities(PredictiveModelQuality... predictiveModelQualities) {
        getPredictiveModelQualities().addAll(Arrays.asList(predictiveModelQualities));
        return this;
    }

    public boolean hasClusteringModelQualities() {
        return ((this.clusteringModelQualities!= null)&&(this.clusteringModelQualities.size()> 0));
    }

    public ModelExplanation addClusteringModelQualities(ClusteringModelQuality... clusteringModelQualities) {
        getClusteringModelQualities().addAll(Arrays.asList(clusteringModelQualities));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasPredictiveModelQualities()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getPredictiveModelQualities());
            }
            if ((status == VisitorAction.CONTINUE)&&hasClusteringModelQualities()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getClusteringModelQualities());
            }
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getCorrelations());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.3.5.jar: org/dmg/pmml/ModelExplanation.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;choice>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_3}PredictiveModelQuality" maxOccurs="unbounded" minOccurs="0"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_3}ClusteringModelQuality" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;/choice>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}Correlations" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "predictiveModelQualities",
    "clusteringModelQualities",
    "correlations"
})
@XmlRootElement(name = "ModelExplanation", namespace = "http://www.dmg.org/PMML-4_3")
@Added(Version.PMML_4_0)
public class ModelExplanation
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<ModelExplanation>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    @XmlElement(name = "PredictiveModelQuality", namespace = "http://www.dmg.org/PMML-4_3")
    private List<PredictiveModelQuality> predictiveModelQualities;
    @XmlElement(name = "ClusteringModelQuality", namespace = "http://www.dmg.org/PMML-4_3")
    private List<ClusteringModelQuality> clusteringModelQualities;
    @XmlElement(name = "Correlations", namespace = "http://www.dmg.org/PMML-4_3")
    private Correlations correlations;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the predictiveModelQualities property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the predictiveModelQualities property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPredictiveModelQualities().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PredictiveModelQuality }
     * 
     * 
     */
    public List<PredictiveModelQuality> getPredictiveModelQualities() {
        if (predictiveModelQualities == null) {
            predictiveModelQualities = new ArrayList<PredictiveModelQuality>();
        }
        return this.predictiveModelQualities;
    }

    /**
     * Gets the value of the clusteringModelQualities property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the clusteringModelQualities property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getClusteringModelQualities().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ClusteringModelQuality }
     * 
     * 
     */
    public List<ClusteringModelQuality> getClusteringModelQualities() {
        if (clusteringModelQualities == null) {
            clusteringModelQualities = new ArrayList<ClusteringModelQuality>();
        }
        return this.clusteringModelQualities;
    }

    /**
     * Gets the value of the correlations property.
     * 
     * @return
     *     possible object is
     *     {@link Correlations }
     *     
     */
    public Correlations getCorrelations() {
        return correlations;
    }

    /**
     * Sets the value of the correlations property.
     * 
     * @param correlations
     *     allowed object is
     *     {@link Correlations }
     *     
     */
    public ModelExplanation setCorrelations(Correlations correlations) {
        this.correlations = correlations;
        return this;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public ModelExplanation addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasPredictiveModelQualities() {
        return ((this.predictiveModelQualities!= null)&&(this.predictiveModelQualities.size()> 0));
    }

    public ModelExplanation addPredictiveModelQualities(PredictiveModelQuality... predictiveModelQualities) {
        getPredictiveModelQualities().addAll(Arrays.asList(predictiveModelQualities));
        return this;
    }

    public boolean hasClusteringModelQualities() {
        return ((this.clusteringModelQualities!= null)&&(this.clusteringModelQualities.size()> 0));
    }

    public ModelExplanation addClusteringModelQualities(ClusteringModelQuality... clusteringModelQualities) {
        getClusteringModelQualities().addAll(Arrays.asList(clusteringModelQualities));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasPredictiveModelQualities()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getPredictiveModelQualities());
            }
            if ((status == VisitorAction.CONTINUE)&&hasClusteringModelQualities()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getClusteringModelQualities());
            }
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getCorrelations());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
